<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'blogable_slider_section', array(
	'title'             => esc_html__( 'Slider','blogable' ),
	'description'       => esc_html__( 'Slider Section options.', 'blogable' ),
	'panel'             => 'blogable_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'blogable_theme_options[slider_section_enable]', 
	array(
		'default'			=> 	$options['slider_section_enable'],
		'sanitize_callback' => 'blogable_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Blogable_Switch_Control( $wp_customize,
	'blogable_theme_options[slider_section_enable]',
			array(
				'label'             => esc_html__( 'Slider Section Enable', 'blogable' ),
				'section'           => 'blogable_slider_section',
				'on_off_label' 		=> blogable_switch_options(),
			)
		)
	);

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'blogable_theme_options[slider_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'blogable_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Blogable_Dropdown_Chooser( $wp_customize,
		'blogable_theme_options[slider_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'blogable'), $i ),
				'section'           => 'blogable_slider_section',
				'choices'			=> blogable_page_choices(),
				'active_callback'	=> 'blogable_is_slider_section_enable',
			)
		)
	);

	// Blogable_Customize_Horizontal_Line
    $wp_customize->add_setting('blogable_theme_options[slider_separator'. $i .']',
		array(
			'sanitize_callback'      => 'blogable_sanitize_html',
		)
	);

    $wp_customize->add_control(new Blogable_Customize_Horizontal_Line($wp_customize,
		'blogable_theme_options[slider_separator'. $i .']',
			array(
				'active_callback'       => 'blogable_is_slider_section_enable',
				'type'                  =>'hr',
				'section'               =>'blogable_slider_section',
			)
		)
	);

endfor;

//slider_btn_txt
$wp_customize->add_setting('blogable_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('blogable_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'blogable_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'blogable' ),
        'type'          	=>'text',
        'active_callback' 	=> 'blogable_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blogable_theme_options[slider_btn_txt]',
		array(
			'selector'            => '#featured-slider-section article div.read-more a:nth-child(1)',
			'settings'            => 'blogable_theme_options[slider_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'blogable_slider_btn_txt_partial',
		) 
	);
}
