<?php
/**
 * Blog section
 *
 * This is the template for the content of popular_post section
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 */
if ( ! function_exists( 'blogable_add_popular_post_section' ) ) :
    /**
    * Add popular_post section
    *
    *@since  Blogable 1.0.0
    */
    function blogable_add_popular_post_section() {
        $options = blogable_get_theme_options();
        // Check if popular_post is enabled on frontpage
        $popular_post_enable = apply_filters( 'blogable_section_status', true, 'popular_post_section_enable' );

        if ( true !== $popular_post_enable ) {
            return false;
        }
        // Get popular_post section details
        $section_details = array();
        $section_details = apply_filters( 'blogable_filter_popular_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render popular_post section now.
        blogable_render_popular_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogable_get_popular_post_section_details' ) ) :
    /**
    * popular_post section details.
    *
    * @since  Blogable 1.0.0
    * @param array $input popular_post section details.
    */
    function blogable_get_popular_post_section_details( $input ) {
        $options = blogable_get_theme_options();

        // Content type.
        $popular_post_count = ! empty( $options['popular_post_count'] ) ? $options['popular_post_count'] : 3;
        
        $content = array();

        $cat_id = ! empty( $options['popular_post_content_category'] ) ? $options['popular_post_content_category'] : '';
        $args = array(
            'post_type'             => 'post',
            'posts_per_page'        => absint( $popular_post_count ),
            'cat'                   => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
        );                    


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blogable_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_post section content details.
add_filter( 'blogable_filter_popular_post_section_details', 'blogable_get_popular_post_section_details' );


if ( ! function_exists( 'blogable_render_popular_post_section' ) ) :
  /**
   * Start popular_post section
   *
   * @return string popular_post content
   * @since  Blogable 1.0.0
   *
   */
   function blogable_render_popular_post_section( $content_details = array() ) {
        $options                = blogable_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="blogable_popular_post_section" class="wrapper page-section same-background">
            <div id="inner-content-wrapper">
                <div id="primary" class="content-area">
                    <main id="main" class="site-main" role="main">
                        <div id="popular-posts-section" class="archive-blog-wrapper col-2 clear">
                        <?php foreach($content_details as $i=>$content) : ?>

                            <article <?php if(($i%3) == 0) echo 'class="full-width"'; ?>>
                                <div class="post-wrapper">
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                                <?php echo the_category('', '', $content['id'])?>
                                            </span><!-- .cat-links -->

                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']);?>" tabindex="0"><?php echo esc_html($content['title']) ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                        </div><!-- .entry-content -->

                                        <div class="post-footer-meta">
                                            <?php echo blogable_author($content['id']); blogable_posted_on($content['id']); ?>

                                            <div class="read-more">
                                                <a href="<?php echo esc_url($content['url']); ?>"><?php esc_html_e('Read Full Post', 'blogable')?></a>
                                            </div>
                                        </div><!-- .entry-meta -->

                                    </div><!-- .entry-container -->
                                </div><!-- .post-wrapper -->
                            </article>
                        <?php endforeach; ?>

                        </div><!-- .archive-blog-wrapper -->
                    </main><!-- #main -->
                </div><!-- #primary -->
                
                <?php if(is_active_sidebar( 'popular-post-section-sidebar' )) : ?>
                    <aside id="secondary" class="widget-area" role="complementary">
                        <?php  dynamic_sidebar( 'popular-post-section-sidebar' ); ?>
                    </aside><!-- #secondary -->
                <?php endif ; ?>
            </div><!-- #inner-content-wrapper-->
        </div>
       
   
    <?php }
endif;  ?>
